<?php
/**
 * Include and setup custom metaboxes and fields.
 *
 * @category YourThemeOrPlugin
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress
 */

add_filter( 'cmb_meta_boxes', 'cmb_sample_metaboxes' );
/**
 * Define the metabox and field configurations.
 *
 * @param  array $meta_boxes
 * @return array
 */
function cmb_sample_metaboxes( array $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_cmb_';
	
    $meta_boxes[] = array(
        'id'         => 'page_setting',
        'title'      => 'Page Setting',
        'pages'      => array('page'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Page Title',
                'desc' => 'Set Page Title',
                'id'   => $prefix . 'page_title',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Page SubTitle',
                'desc' => 'Set Page SubTitle',
                'id'   => $prefix . 'page_stitle',
                'type'    => 'text',
            ),
            array(
                'name' => 'Upload Background Image Top',
                'desc' => 'Recommend: 1920x1280',
                'id' => $prefix . 'bg_head',
                'type' => 'file',
                'allow' => array( 'url', 'attachment' ) // limit to just attachments with array( 'attachment' )
            ),         
        )
    );
	// Add other metaboxes as needed	
	
	$meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Upload Background Image for Top Single Blog Page',
                'desc' => 'Upload an image or enter an URL, Recommended Size: 1900 x 1024.',
                'id' => $prefix . 'image_thumbnail',
                'type' => 'file',
                'allow' => array( 'url', 'attachment' ) // limit to just attachments with array( 'attachment' )
            ), 
            array(
                'name' => __( 'Content Right', 'cmb' ),
                'desc' => __( 'Content Right Title', 'cmb' ),
                'id'   => $prefix . 'right_text',
                'type' => 'textarea'
            ),
            array(
                'name' => __( 'Excerpt Post', 'cmb' ),
                'desc' => __( 'Text show on blog page', 'cmb' ),
                'id'   => $prefix . 'ex_post',
                'type' => 'textarea'
            ),
                     
        )
    );

    $meta_boxes[] = array(
        'id'         => 'portfolio_setting',
        'title'      => 'Portfolio Setting',
        'pages'      => array('portfolio', 'slide'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Upload Background Image Top',
                'desc' => '',
                'id' => $prefix . 'bg_folio',
                'type' => 'file',
                'allow' => array( 'url', 'attachment' ) // limit to just attachments with array( 'attachment' )
            ),
            array(
                'name' => 'Top Title',
                'desc' => '',
                'id'   => $prefix . 'folio_title',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Top SubTitle',
                'desc' => '',
                'id'   => $prefix . 'folio_stitle',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Video Link Popup',
                'desc' => 'Only use for Portfolio Lightbox Video. <br>Ex: http://player.vimeo.com/video/88883554 or http://www.youtube.com/embed/eP2VWNtU5rw',
                'id'   => $prefix . 'folio_video',
                'type'    => 'text',
            ),      
        )
    );
	
	return $meta_boxes;
}

add_action( 'init', 'cmb_initialize_cmb_meta_boxes', 9999 );
/**
 * Initialize the metabox class.
 */
function cmb_initialize_cmb_meta_boxes() {

	if ( ! class_exists( 'cmb_Meta_Box' ) )
		require_once 'init.php';

}
