<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "theme_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'theme_option',
        'use_cdn' => TRUE,
        'display_name'     => $theme->get('Name'),
        'display_version'  => $theme->get('Version'),
        'page_title' => 'Pallas Options',
        'update_notice' => FALSE,
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Pallas Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => FALSE,
        'dev_mode'   => false,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );    

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'pallas' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'pallas' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'pallas' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'pallas' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'This is the sidebar content, HTML is allowed.', 'pallas' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // ACTUAL DECLARATION OF SECTIONS  
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-repeat',
        'title' => __('Preload Settings', 'pallas'),
        'fields' => array(
            array(
                'id' => 'show_pre',
                'type' => 'select',
                'title' => __('Show Preload?', 'pallas'),
                'subtitle' => __('Option Show Preload', 'pallas'),
                'desc' => __('', 'pallas'),
                'options'  => array(
                    'yes' => 'Yes',
                    'no'  => 'No',
                ),
                'default' => 'yes',
            ),  
            array(
                'id' => 'gmap_apikey',
                'type' => 'text',
                'title' => __('Google Map API Key', 'pallas'),
                'subtitle' => __('Add your google map api key, create here: https://developers.google.com/maps/documentation/javascript/', 'pallas'),
                'default' => 'AIzaSyAvpnlHRidMIU374bKM5-sx8ruc01OvDjI'
            ),                
         )
    ) );  
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-picture',
        'title' => __('Logo & Favicon Settings', 'pallas'),
        'fields' => array(
            array(
                'id' => 'favicon',
                'type' => 'media',
                'url' => false,
                'title' => __('Custom Favicon', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Favicon.', 'pallas'),
                'subtitle' => __('', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/favicon.png'),
            ),
            array(
                'id'   =>'divider_1',
                'desc' => __('', 'pallas'),
                'type' => 'divide'
            ),
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => false,
                'title' => __('Logo static', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your logo static.', 'pallas'),
                'subtitle' => __('Recommended size: Height: 25px and Width: 134px', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/logo.png'),
            ),
            array(
                'id' => 'logo_width',
                'type' => 'text',
                'title' => __('Fix Width Logo static, Default: 134px', 'pallas'),
                'subtitle' => __('Input Width logo', 'pallas'),
                'default' => '134px'
            ),  
            array(
                'id' => 'logo_height',
                'type' => 'text',
                'title' => __('Fix Height Logo static, Default: 25px', 'pallas'),
                'subtitle' => __('Input Height Logo', 'pallas'),
                'default' => '25px'
            ),  
            array(
                'id' => 'logo_margintop',
                'type' => 'text',
                'title' => __('Margin top for logo static, Default: 50px', 'pallas'),
                'subtitle' => __('Input Margin Top Logo', 'pallas'),
                'default' => '50px'
            ), 
            array(
                'id'   =>'divider_2',
                'desc' => __('', 'pallas'),
                'type' => 'divide'
            ),
            array(
                'id' => 'logo2',
                'type' => 'media',
                'url' => false,
                'title' => __('Logo scroll', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your logo scroll.', 'pallas'),
                'subtitle' => __('Recommended size: Height: 16px and Width: 86px', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/logo.png'),
            ),
            array(
                'id' => 'logo_width2',
                'type' => 'text',
                'title' => __('Fix Width Logo scroll, Default: 86px', 'pallas'),
                'subtitle' => __('Input Width logo scroll', 'pallas'),
                'default' => '86px'
            ),  
            array(
                'id' => 'logo_height2',
                'type' => 'text',
                'title' => __('Fix Height Logo scroll, Default: 16px', 'pallas'),
                'subtitle' => __('Input Height Logo scroll', 'pallas'),
                'default' => '16px'
            ),  
            array(
                'id' => 'logo_margintop2',
                'type' => 'text',
                'title' => __('Margin top for logo scroll, Default: 32px', 'pallas'),
                'subtitle' => __('Input Margin Top Logo', 'pallas'),
                'default' => '32px'
            ),
            array(
                'id'   =>'divider_3',
                'desc' => __('', 'pallas'),
                'type' => 'divide'
            ),
            array(
                'id' => 'logomobile_width',
                'type' => 'text',
                'title' => __('Fix Width Logo mobile, Default: 80px', 'pallas'),
                'subtitle' => __('Input Width logo mobile', 'pallas'),
                'default' => '80px'
            ),  
            array(
                'id' => 'logomobile_height',
                'type' => 'text',
                'title' => __('Fix Height Logo mobile, Default: 15px', 'pallas'),
                'subtitle' => __('Input Height Logo mobile', 'pallas'),
                'default' => '15px'
            ),  
            array(
                'id' => 'logomobile_margintop',
                'type' => 'text',
                'title' => __('Margin top for logo, Default: 30px', 'pallas'),
                'subtitle' => __('Input Margin Top Logo', 'pallas'),
                'default' => '30px'
            ),
            array(
                'id'   =>'divider_4',
                'desc' => __('', 'pallas'),
                'type' => 'divide'
            ),
            array(
                'id' => 'apple_icon',
                'type' => 'media',
                'url' => false,
                'title' => __('Apple Touch Icon 57x57', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Apple touch icon 57x57.', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon.png'),
            ),                  
            array(
                'id' => 'apple_icon_72',
                'type' => 'media',
                'url' => false,
                'title' => __('Apple Touch Icon 72x72', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Apple touch icon 72x72.', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon-72x72.png'),
            ),
            array(
                'id' => 'apple_icon_114',
                'type' => 'media',
                'url' => false,
                'title' => __('Apple Touch Icon 114x114', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Apple touch icon 114x114.', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon-114x114.png'),
            ),                  
        )
    ) );                      
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-font',
        'title' => __('Typography', 'pallas'),
        'fields' => array(
            array(
                'id' => 'h1-typography',
                'type' => 'typography',
                'output' => array('h1'),
                'title' => __('Heading 1', 'pallas'),
                'subtitle' => __('Specify the heading 1 font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ),   
            array(
                'id' => 'h2-typography',
                'type' => 'typography',
                'output' => array('h2'),
                'title' => __('Heading 2', 'pallas'),
                'subtitle' => __('Specify the heading 2 font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h3-typography',
                'type' => 'typography',
                'output' => array('h3'),
                'title' => __('Heading 3', 'pallas'),
                'subtitle' => __('Specify the heading 3 font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h4-typography',
                'type' => 'typography',
                'output' => array('h4'),
                'title' => __('Heading 4', 'pallas'),
                'subtitle' => __('Specify the heading 4 font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h5-typography',
                'type' => 'typography',
                'output' => array('h5'),
                'title' => __('Heading 5', 'pallas'),
                'subtitle' => __('Specify the heading 5 font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h6-typography',
                'type' => 'typography',
                'output' => array('h6'),
                'title' => __('Heading 6', 'pallas'),
                'subtitle' => __('Specify the heading 6 font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ),    

            array(
                'id' => 'menu-typography',
                'type' => 'typography',
                'output' => array('ul.slimmenu li a'),
                'title' => __('Menu item', 'pallas'),
                'subtitle' => __('Specify the Menu item font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => '',
                ),
            ),                                   
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-blogger',
        'title' => __('Blog Settings', 'pallas'),
        'fields' => array(   
            array(
                'id'       => 'blog_layout',
                'type'     => 'image_select',
                'title'    => __( 'Blog Layout', 'ananke' ),
                'subtitle' => __( 'Click on image layout to chooise', 'ananke' ),
                'desc'     => __( 'Select layout you want use for all your blog page.', 'ananke' ),
                //Must provide key => value(array:title|img) pairs for radio options
                'options'  => array(
                    'fw' => array(
                        'alt' => '1 Column',
                        'img' => get_template_directory_uri().'/images/theme-options/1c.png'
                    ),                    
                    'wsbl' => array(
                        'alt' => '2 Column Left',
                        'img' => get_template_directory_uri().'/images/theme-options/2cl.png'
                    ),    
                    'wsb' => array(
                        'alt' => '2 Column Right',
                        'img' => get_template_directory_uri().'/images/theme-options/2cr.png'
                    ),                                 
                ),
                'default'  => 'wsb'
            ),   
            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => __('Blog Title', 'pallas'),
                'subtitle' => __('Input Blog Title', 'pallas'),
                'desc' => __('', 'pallas'),
                'default' => 'Blog & News<span>.</span>'
            ),      
            array(
                'id' => 'blog_subtitle',
                'type' => 'text',
                'title' => __('Blog Subtitle', 'pallas'),
                'subtitle' => __('Input Blog Subtitle', 'pallas'),
                'desc' => __('', 'pallas'),
                'default' => '- you can not hold up a blog -'
            ),                  
            array(
                'id' => 'read_more',
                'type' => 'text',
                'title' => __('Button Text For Post', 'pallas'),
                'subtitle' => __('Input Button Text', 'pallas'),
                'desc' => __('', 'pallas'),
                'default' => 'Read more'
            ),
            array(
                'id' => 'single_layout',
                'type' => 'select',
                'title' => __('Single Blog Layout', 'pallas'),
                'subtitle' => __('', 'pallas'),
                'desc' => __('Select Single Blog Layout for Single Blog Page.', 'pallas'),
                'options'  => array(
                    'withsidebar' => 'Single Width Sidebar',
                    'fullwidth'  => 'Single FullWidth & Use Visual Composer',                                                        
                ),
                'default' => 'withsidebar',
            ), 
            array(
                'id' => 'comment',
                'type' => 'select',
                'title' => __('Show Comment?', 'pallas'),
                'subtitle' => __('Option Show Comment', 'pallas'),
                'desc' => __('', 'pallas'),
                'options'  => array(
                    'yes' => 'Yes',
                    'no'  => 'No',
                ),
                'default' => 'no',
            ),
            array(
                'id' => 'blog_thumbnail',
                'type' => 'media',
                'url' => false,
                'title' => __('Blog Background Top Page', 'pallas'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Blog Background Top Page.', 'pallas'),
                'subtitle' => __('', 'pallas'),
                'default' => array('url' => get_template_directory_uri().'/images/blog.jpg'),
            ),
         )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-briefcase',
        'title' => __('Portfolio Settings', 'pallas'),
        'fields' => array(
            array(
                'id' => 'show_all',
                'type' => 'text',
                'title' => __('Text Show All Filter', 'pallas'),
                'subtitle' => __('', 'pallas'),
                'desc' => __('', 'pallas'),
                'default' => 'All'
            ),                    
         )
    ) );

    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-credit-card',
        'title' => __('Footer Settings', 'pallas'),
        'fields' => array(  
            array(
                'id' => 'social_style',
                'type' => 'select',
                'title' => __('Social Media Style.', 'archi'),                        
                'desc' => __('Select Social Media Style : show button text or button icon.', 'archi'),
                'options'  => array(
                    'btntext' => 'Button text',
                    'btnicon' => 'Button icon',                                                                         
                ),
                'default' => 'btntext',
            ),                  
            array(
                'id' => 'footer_text',
                'type' => 'editor',
                'title' => __('Footer Text', 'pallas'),
                'subtitle' => __('Copyright Text', 'pallas'),
                'default' => '<p>© We are Pallas. All rights reserved. 2019<br>
                                Develop by OceanThemes in Kraljevo, Serbia</p>',
            ),
            array(
                'id' => 'facebook',
                'type' => 'text',
                'title' => __('Facebook Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://www.facebook.com/',
            ),
            array(
                'id' => 'google',
                'type' => 'text',
                'title' => __('Google+ Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://plus.google.com',
            ),
            array(
                'id' => 'twitter',
                'type' => 'text',
                'title' => __('Twitter Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://twitter.com/',
            ),
            array(
                'id' => 'github',
                'type' => 'text',
                'title' => __('Github Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'youtube',
                'type' => 'text',
                'title' => __('Youtube Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'linkedin',
                'type' => 'text',
                'title' => __('Linkedin Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'dribbble',
                'type' => 'text',
                'title' => __('Dribbble Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'pinterest',
                'type' => 'text',
                'title' => __('Pinterest Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'behance',
                'type' => 'text',
                'title' => __('Behance Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'vimeo',
                'type' => 'text',
                'title' => __('Vimeo Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'vk',
                'type' => 'text',
                'title' => __('Vk Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'flickr',
                'type' => 'text',
                'title' => __('Flickr Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'instagram',
                'type' => 'text',
                'title' => __('Instagram Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'skype',
                'type' => 'text',
                'title' => __('Skype Url', 'pallas'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),      
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-website',
        'title' => __('Styling Options', 'pallas'),
        'fields' => array(
            array(
                'id' => 'main-color',
                'type' => 'color',
                'title' => __('Theme Main Color', 'pallas'),
                'subtitle' => __('Pick the main color for the theme (default: #F89406).', 'pallas'),
                'default' => '#F89406',
                'validate' => 'color',
            ),              
            array(
                'id' => 'body-font2',
                'type' => 'typography',
                'output' => array('body'),
                'title' => __('Body Font', 'pallas'),
                'subtitle' => __('Specify the body font properties.', 'pallas'),
                'google' => true,
                'default' => array(
                    'color' => '',
                    'font-size' => '',
                    'line-height' => '',
                    'font-family' => '',
                    'font-weight' => ''
                ),
            ),
             array(
                'id' => 'custom-css',
                'type' => 'ace_editor',
                'title' => __('CSS Code', 'pallas'),
                'subtitle' => __('Paste your CSS code here.', 'pallas'),
                'mode' => 'css',
                'theme' => 'monokai',
                'desc' => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
                'default' => "#header{\nmargin: 0 auto;\n}"
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(        
        'title' => __('Header Styling', 'pallas'),
        'id'         => 'header-style', 
        'subsection' => true,
        'fields' => array(
            array(
                'id' => 'header_background',
                'type' => 'color_rgba',
                'title' => __('Header Background Color', 'pallas'),
                'subtitle' => __('Pick a background color for the header (default: #F7F7F7).', 'pallas'),
                'default'   => array(
                    'color'     => '#F7F7F7',
                    'alpha'     => .8
                ),
                'output' => array('background-color' => '.menu-back')
            ),
            array(
                'id' => 'header_color',
                'type' => 'color',
                'title' => __('Header Text Color', 'pallas'),
                'subtitle' => __('Pick a  color for the header (default: #111111).', 'pallas'),
                'default' => '#111111',                
                'output' => array( 'color' => 'ul.slimmenu li a' )
            ),
            array(
                'id' => 'header_scroll_background',
                'type' => 'color_rgba',
                'title' => __('Header Scroll Background Color', 'pallas'),
                'subtitle' => __('Pick a background color for the header scroll (default: #F7F7F7).', 'pallas'),
                'default'   => array(
                    'color'     => '#F7F7F7',
                    'alpha'     => .95
                ),
                'output' => array('background-color' => '.cbp-af-header.cbp-af-header-shrink')
            ),
            array(
                'id' => 'header_scroll_color',
                'type' => 'color',
                'title' => __('Header Scroll Text Color', 'pallas'),
                'subtitle' => __('Pick a  color for the header scroll (default: #111111).', 'pallas'),
                'default' => '#111111',                
                'output' => array( 'color' => '.cbp-af-header.cbp-af-header-shrink ul.slimmenu li a' )
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(        
        'title' => __('Footer Styling', 'pallas'),
        'id'         => 'footer-style', 
        'subsection' => true,
        'fields' => array(
            array(
                'id' => 'background_footer',
                'type' => 'color',
                'title' => __('Footer Background Color', 'pallas'),
                'subtitle' => __('Pick a background color for the footer (default: #efefef).', 'pallas'),
                'default' => '#efefef',
                'validate' => 'color',
            ),
            array(
                'id' => 'color_footer',
                'type' => 'color',
                'title' => __('Footer Color', 'pallas'),
                'subtitle' => __('Pick a  color for the footer (default: #999999).', 'pallas'),
                'default' => '#999999',
                'validate' => 'color',
            ),
            array(
                'id' => 'color_social',
                'type' => 'color',
                'title' => __('Footer Social Color', 'pallas'),
                'subtitle' => __('Pick a  color for social footer (default: #212121).', 'pallas'),
                'default' => '#212121',
                'validate' => 'color',
            ),
        )
    ) );    

    /*
     * <--- END SECTIONS
     */