<?php
/**
 * Redux Theme functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package mentor
 */

if ( ! class_exists( 'ReduxFramewrk' ) ) {
    require_once( get_template_directory() . '/framework/sample-config.php' );
	function pallas_removeDemoModeLink() { // Be sure to rename this function to something more unique
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
		}
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
		}
	}
	add_action('init', 'pallas_removeDemoModeLink');
}

if ( ! function_exists( 'pallas_theme_setup' ) ) :
	function pallas_theme_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on _s, use a find and replace
		 * to change 'onum' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'pallas', get_template_directory() . '/languages' );


		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

	    /*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

	    /*
		 * Enable support for Post Formats.
		 *
		 * See: https://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array(
			'image',
			'video',
			'quote',
			'gallery',
			'audio',
			'link',
		) );

		/* Add image sizes */
		add_image_size( 'thumb-portfolio', 900, 700, true ); // 220 pixels wide by 180 pixels tall, hard crop mode
		add_image_size( 'thumb-portfolio-small', 600, 400, true ); // 220 pixels wide by 180 pixels tall, hard crop mode

	    // This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary'   => 'Primary Menu',
		) );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, and column width.
	 	 */
		add_editor_style( array( 'css/editor-style.css', pallas_fonts_url() ) );

	    // This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );
	    add_shortcode('gallery', '__return_false');
	}
endif;
add_action( 'after_setup_theme', 'pallas_theme_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function pallas_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'pallas_content_width', 900 );
}
add_action( 'after_setup_theme', 'pallas_content_width', 0 );


/**
 * Register custom fonts.
 */
if ( ! function_exists( 'pallas_fonts_url' ) ) :
/**
 * Register Google fonts for Pallas.
 *
 * Create your own pallas_fonts_url() function to override in a child theme.
 *
 * @since Pallas 1.7.2
 *
 * @return string Google fonts URL for the theme.
 */
function pallas_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,cyrillic-ext,greek-ext,greek,vietnamese,latin-ext,cyrillic';

	/* translators: If there are characters in your language that are not supported by Montserrat, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Montserrat font: on or off', 'pallas' ) ) {
		$fonts[] = 'Montserrat:400,700';
	}
	/* translators: If there are characters in your language that are not supported by Lato, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Lato font: on or off', 'pallas' ) ) {
		$fonts[] = 'Lato:100,300,400,700,900,100italic,300italic,400italic,700italic,900italic';
	}
	/* translators: If there are characters in your language that are not supported by Open Sans, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Open+Sans font: on or off', 'pallas' ) ) {
		$fonts[] = 'Open Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800';
	}
	/* translators: If there are characters in your language that are not supported by Satisfy, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Satisfy font: on or off', 'pallas' ) ) {
		$fonts[] = 'Satisfy';
	}
	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}
	return $fonts_url;
}
endif;

function pallas_theme_scripts_styles() {
	global $theme_option;
	$gmapaipkey = $theme_option['gmap_apikey'];
	$protocol = is_ssl() ? 'https' : 'http';

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'pallas-fonts', pallas_fonts_url(), array(), null );

	wp_enqueue_style( 'pallas-base', get_template_directory_uri().'/css/base.css');
	wp_enqueue_style( 'pallas-skeleton', get_template_directory_uri().'/css/skeleton.css');	
	wp_enqueue_style( 'pallas-font-awesome', get_template_directory_uri().'/css/font-awesome/css/font-awesome.min.css');
	wp_enqueue_style( 'pallas-animsition', get_template_directory_uri().'/css/animsition.min.css');
	wp_enqueue_style( 'pallas-carousel', get_template_directory_uri().'/css/owl.carousel.css');
	wp_enqueue_style( 'pallas-colorbox', get_template_directory_uri().'/css/colorbox.css');
	wp_enqueue_style( 'pallas-retina', get_template_directory_uri().'/css/retina.css');
	wp_enqueue_style( 'pallas-style', get_stylesheet_uri(), array(), '2017-07-27' );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ){
    	wp_enqueue_script( 'comment-reply' );
	}

	if ($gmapaipkey != '') {
		wp_enqueue_script("pallas-mapapi", "$protocol://maps.googleapis.com/maps/api/js?key=$gmapaipkey",array('jquery'),false,false);
	}

	wp_enqueue_script("pallas-modernizr", get_template_directory_uri()."/js/modernizr.custom.js",array('jquery'),false,false);
	wp_enqueue_script("pallas-bgndGallery", get_template_directory_uri()."/js/mb.bgndGallery.js",array('jquery'),false,false);	
	wp_enqueue_script("pallas-plugins", get_template_directory_uri()."/js/plugins.js",array('jquery'),false,true);
	wp_enqueue_script("pallas-YTPlayer", get_template_directory_uri()."/js/YTPlayer.js",array('jquery'),false,false);
	wp_enqueue_script("pallas-template", get_template_directory_uri()."/js/template.js",array('jquery'),false,true); 
	wp_enqueue_script("pallas-blog", get_template_directory_uri()."/js/custom-blog.js",array('jquery'),false,true); 
}
add_action( 'wp_enqueue_scripts', 'pallas_theme_scripts_styles');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function pallas_widgets_init() {
	register_sidebar( array(
        'name'          => __( 'Primary Sidebar', 'pallas' ),
        'id'            => 'sidebar-1',        
		'description'   => __( 'Appears in the sidebar section of the site.', 'pallas' ),        
		'before_widget' => '<div id="%1$s" class="widget %2$s">',        
		'after_widget'  => '</div>',        
		'before_title'  => '<h6>',        
		'after_title'   => '</h6>'
    ) );
}
add_action( 'widgets_init', 'pallas_widgets_init' );

//function tag widgets
function pallas_tag_cloud_widget($args) {
	$args['number'] = 0; //adding a 0 will display all tags
	$args['largest'] = 18; //largest tag
	$args['smallest'] = 11; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['format'] = 'list'; //ul with a class of wp-tag-cloud
	$args['exclude'] = ''; //exclude tags by ID
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'pallas_tag_cloud_widget' );

function pallas_excerpt() {
  global $theme_option;
  if(isset($theme_option['blog_excerpt'])){
    $limit = $theme_option['blog_excerpt'];
  }else{
    $limit = 15;
  }
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

// Excerpt Section Blog Post
function pallas_blog_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

//pagination
function pallas_pagination($prev = '<i class="fa fa-chevron-left"></i>', $next = '<i class="fa fa-chevron-right"></i>', $pages='') {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    if($pages==''){
        global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
    }
    $pagination = array(
		'base' 			=> str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
		'format' 		=> '',
		'current' 		=> max( 1, get_query_var('paged') ),
		'total' 		=> $pages,
		'prev_text' => $prev,
        'next_text' => $next,		
		'type'			=> 'list',
		'end_size'		=> 3,
		'mid_size'		=> 3
);
    $return =  paginate_links( $pagination );
	echo str_replace( "<ul class='page-numbers'>", '<ul>', $return );
}

function pallas_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform" class="search_form" action="' . home_url( '/' ) . '" >  
    	<input type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="'.__('type to search and hit enter', 'pallas').'" />
    </form>';
    return $form;
}
add_filter( 'get_search_form', 'pallas_search_form' );

// Comment Form
function pallas_theme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <div class="post-content-comment grey-section">
		<?php echo get_avatar($comment,$size='70',$default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=70' ); ?>
		<h6><?php printf(__('%s','pallas'), get_comment_author_link()) ?></h6>
		<?php if ($comment->comment_approved == '0'){ ?>
			 <p><em><?php _e('Your comment is awaiting moderation.','pallas') ?></em></p>
		<?php }else{ ?>
        <?php comment_text() ?>
		<?php } ?>
		<div class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></div> 
	<div class="clearfix"></div>	
	</div> 
<?php
}

//if(class_exists('WPBakeryVisualComposerSetup')){
function custom_css_classes_for_vc_row_and_vc_column($class_string, $tag) {
    if($tag=='vc_row' || $tag=='vc_row_inner') {
        $class_string = str_replace('vc_row-fluid', '', $class_string);
    }
    if($tag=='vc_column' || $tag=='vc_column_inner') {
		$class_string = preg_replace('/vc_col-sm-12/', 'sixteen columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-6/', 'eight columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-4/', 'one-third column', $class_string);
		$class_string = preg_replace('/vc_col-sm-3/', 'four columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-5/', 'seven columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-7/', 'nine columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-8/', 'two-thirds column', $class_string);
		$class_string = preg_replace('/vc_col-sm-9/', 'twelve columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-10/', 'thirteen column', $class_string);
		$class_string = preg_replace('/vc_col-sm-11/', 'fifteen columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-1/', 'one columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-2/', 'three columns', $class_string);
    }
    return $class_string;
}
// Filter to Replace default css class for vc_row shortcode and vc_column
add_filter('vc_shortcodes_css_class', 'custom_css_classes_for_vc_row_and_vc_column', 10, 2); 

// Add new Param in Row
if(function_exists('vc_add_param')){
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => __('Extra id name', 'pallas'),
                              "param_name" => "extra_id",
                              "value" => "",
                              "description" => __("If you wish to style particular content element differently, then use this field to add a id name and then refer to it in your css file.", "pallas"),   
    ));	

vc_add_param('vc_row',array(
                              "type" => "dropdown",
                              "heading" => __('Fullwidth', 'pallas'),
                              "param_name" => "fullwidth",
                              "value" => array(   
                                                __('No', 'pallas') => 'no',  
                                                __('Yes', 'pallas') => 'yes',                                                                                
                                              ),
                              "description" => __("Select Fullwidth or not, Default: No fullwidth", "pallas"),      
                            ) 
    );
	
// Add new Param in Column
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => __('Container Class', 'pallas'),
                              "param_name" => "wap_class",
                              "value" => "",
                              "description" => __("Container Class", "pallas"),      
                            ) 
    );

vc_remove_param( "vc_row", "el_id" );
vc_remove_param( "vc_row", "full_width" );
vc_remove_param( "vc_column", "offset" );
}
//}

/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/framework/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'pallas_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function pallas_theme_register_required_plugins() {

	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(

		// This is an example of how to include a plugin from the WordPress Plugin Repository.
		array(
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),
		array(
            'name'                     => 'Redux Framework', // The plugin name
            'slug'                     => 'redux-framework', // The plugin slug (typically the folder name)
            'required'                 => false, // If false, the plugin is only 'recommended' instead of required
        ),

		// This is an example of how to include a plugin from a private repo in your theme.
		array(            
			'name'               => 'WPBakery Visual Composer', // The plugin name.
            'slug'               => 'js_composer', // The plugin slug (typically the folder name).
            'source'             => 'http://oceanthemes.net/plugins-required/js_composer.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '6.0.5', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
            'is_callable'        => '', // If set, this callable will be be checked for availability to determine if a plugin is active.
        ),          
		array(            
			'name'               => 'OT Portfolio', // The plugin name.
            'slug'               => 'ot_portfolio', // The plugin slug (typically the folder name).
            'source'             => 'http://oceanthemes.net/plugins-required/ot_portfolio.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '1.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
            'is_callable'        => '', // If set, this callable will be be checked for availability to determine if a plugin is active.
        ),         
		array(            
            'name'               => 'OT One Click Import Demo Content', // The plugin name.
            'slug'               => 'ot-themes-one-click-import', // The plugin slug (typically the folder name).
            'source'             => 'http://oceanthemes.net/plugins-required/pallas/ot-themes-one-click-import.zip',
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ), 				
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are wrapped in a sprintf(), so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to pre-packaged plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
		'strings'      => array(
			'page_title'                      => __( 'Install Required Plugins', 'theme-slug' ),
			'menu_title'                      => __( 'Install Plugins', 'theme-slug' ),
			'installing'                      => __( 'Installing Plugin: %s', 'theme-slug' ), // %s = plugin name.
			'oops'                            => __( 'Something went wrong with the plugin API.', 'theme-slug' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop(
				'Sorry, but you do not have the correct permissions to install the %s plugin.',
				'Sorry, but you do not have the correct permissions to install the %s plugins.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop(
				'Sorry, but you do not have the correct permissions to activate the %s plugin.',
				'Sorry, but you do not have the correct permissions to activate the %s plugins.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop(
				'Sorry, but you do not have the correct permissions to update the %s plugin.',
				'Sorry, but you do not have the correct permissions to update the %s plugins.',
				'theme-slug'
			), // %1$s = plugin name(s).
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'theme-slug'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'theme-slug'
			),
			'return'                          => __( 'Return to Required Plugins Installer', 'theme-slug' ),
			'plugin_activated'                => __( 'Plugin activated successfully.', 'theme-slug' ),
			'complete'                        => __( 'All plugins installed and activated successfully. %s', 'theme-slug' ), // %s = dashboard link.
			'contact_admin'                   => __( 'Please contact the administrator of this site for help.', 'tgmpa' ),

			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		)
	);
	tgmpa( $plugins, $config );
}

/** customize theme option for color **/
require get_template_directory() . '/framework/color.php';

/**
 * Shortcode elements.
 */
require get_template_directory() . '/vc_shortcode.php';
require get_template_directory() . '/shortcodes.php';

/**
 * Custom metabox.
 */
require get_template_directory() . '/framework/Custom-Metaboxes/metabox-functions.php';
?>